@@ -35,7 +35,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL.php,v 1.49 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL.php,v 1.50 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -43,7 +43,7 @@
 /**
  * С
  */
-define('SYL_VERSION', '0.15.3');
+define('SYL_VERSION', '0.15.4');
 
 /**
  * ١ǥ쥯ȥ
@@ -77,18 +77,6 @@ if (version_compare(PHP_VERSION, '5.1.0', '>=') && !ini_get('date.timezone')) {
     date_default_timezone_set('Asia/Tokyo');
 }
 
-/**
- * PHPƥ२顼¸
- * ȤǥƤʤ硢¸
- */
-if (!ini_get('log_errors')) {
-    $_log = SYL_DIR . '/var/syslogs/phperror_' . date('Ymd') . '.log';
-    if (is_writable(dirname($_log))) {
-        ini_set('log_errors', true);
-        ini_set('error_log', $_log);
-    }
-}
-
 // ȥɤ߹
 require_once SYL_INCLUDE_DIR . '/framework/SyL_Controller.php';
 
