@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.8 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.9 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.8 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.9 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowNew extends SyL_AdmFlow
@@ -114,13 +114,13 @@ class SyL_AdmFlowNew extends SyL_AdmFlow
             // ؿʤ
             if ($data->get('adm_action_next')) {
                 // Хǡ¹
-                if ($this->validate($adm)) {
+                if ($this->validateAdm($adm)) {
                     // ǧ̤
                     $form->setReadOnly(true);
                 }
             } else if ($data->get('adm_action_exe')) {
                 // Хǡ¹
-                if ($this->validate($adm)) {
+                if ($this->validateAdm($adm)) {
                     // Ͽ¹
                     $this->insert($adm);
                     // λ̤إ쥯
@@ -164,7 +164,7 @@ class SyL_AdmFlowNew extends SyL_AdmFlow
      * @param object ADM֥
      * @return bool true: ХǡOKfalse: Хǡ󥨥顼
      */
-    function validate(&$adm)
+    function validateAdm(&$adm)
     {
         return $adm->validate();
     }
