@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.9 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.10 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.9 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.10 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperationLst extends SyL_AdmOperation
@@ -132,13 +132,26 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
                 }
             } 
             $table->setConditions($conditions);
-            // 
+
+            // Ⱦ
+            $primarys = array();
+            if ($alias == $this->form->getMaintenanceTable()) {
+                $primarys = $this->getPrimary(true);
+            }
             foreach ($sorts as $sort) {
-                list($alias_tmp) = explode('.', $sort, 2);
+                list($alias_tmp, $column_tmp) = explode('.', $sort, 3);
                 if ($alias == $alias_tmp) {
                     $table->addSortLink($sort);
+                    $key = array_search("{$alias_tmp}.{$column_tmp}", $primarys);
+                    if ($key !== false) {
+                        unset($primarys[$key]);
+                    }
                 }
             }
+            foreach ($primarys as $primary) {
+                $table->addSortLink("{$primary}.ASC");
+            }
+
             $tables[$alias] =& $table;
         }
 
