@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.28 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.29 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,11 +44,18 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Action.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.28 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.29 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
 {
+    /**
+     * ե̾
+     * 
+     * @access private
+     * @var string
+     */
+    var $config_file_name = 'actions.xml';
     /**
      * ٥̾
      * 
@@ -99,17 +106,28 @@ class SyL_ConfigActions extends SyL_Config
      */
     var $action_key = SYL_ACTION_KEY;
 
+    /**
+     * ե򥻥å
+     *
+     * @access protected
+     */
+    function setProjectConfigFiles()
+    {
+        $this->file_names[] = SYL_APP_CONFIG_DIR . "/{$this->config_file_name}";
+    }
+
     /**
      * XMLեβϽ
      *
      * @access public
+     * @param bool åͭե饰
      */
-    function parseXml()
+    function parseXml($enable_cache=true)
     {
         // ١饹
         SyL_Loader::lib(SYL_ACTION_BASE_CLASS);
 
-        if (SYL_CACHE) {
+        if (SYL_CACHE && $enable_cache) {
             // åѤ
             $key = SYL_APP_DIR . $this->context->getActionFile() . $this->context->getActionName();
             $cache =& $this->getCache($key);
