@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.11 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.12 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,19 +39,38 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.11 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.12 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigLayouts extends SyL_Config
 {
+    /**
+     * ե̾
+     * 
+     * @access private
+     * @var string
+     */
+    var $config_file_name = 'layouts.xml';
+
+    /**
+     * ե򥻥å
+     *
+     * @access protected
+     */
+    function setProjectConfigFiles()
+    {
+        $this->file_names[] = SYL_APP_CONFIG_DIR . "/{$this->config_file_name}";
+    }
+
     /**
      * XMLեβϽ
      *
      * @access public
+     * @param bool åͭե饰
      */
-    function parseXml()
+    function parseXml($enable_cache=true)
     {
-        if (SYL_CACHE) {
+        if (SYL_CACHE && $enable_cache) {
             // åѤ
             $key = SYL_APP_DIR . $this->context->getActionFile();
             $cache =& $this->getCache($key);
