@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataJs.php,v 1.7 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataJs.php,v 1.8 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataJs.php,v 1.7 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataJs.php,v 1.8 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DataJs extends SyL_Data
@@ -51,13 +51,6 @@ class SyL_DataJs extends SyL_Data
      * @var string
      */
     var $javascript = '';
-    /**
-     * ѥ᡼get᥽åɤǼǤե饰
-     *
-     * @access protected
-     * @var bool
-     */
-    var $input_get_array = false;
     /**
      * JavaScriptϥ饹
      * 
@@ -94,75 +87,6 @@ class SyL_DataJs extends SyL_Data
      */
     var $js_callback_parameter = 'callback';
 
-    /**
-     * ץѥƥ
-     * 
-     * @access public
-     * @param string ץѥƥ̾
-     * @param mixed ǥե
-     * @param string ͭɽ
-     * @return string ץѥƥ
-     */
-    function get($name, $default=null, $reg=null)
-    {
-        $value = parent::get($name, $default, $reg);
-        if (!$this->input_get_array) {
-            if (isset($this->input_parameters[$name]) && is_array($value) && ($this->input_parameters[$name] === $value)) {
-                // ϥѥ᡼ϡgeta᥽åɤŪ˼
-                $value = null;
-            }
-        }
-        return $value;
-    }
-
-    /**
-     * ץѥƥʻȡ
-     * 
-     * @access public
-     * @param string ץѥƥ̾
-     * @param mixed ǥե
-     * @param string ͭɽ
-     * @return string ץѥƥ
-     */
-    function &getRef($name, $default=null, $reg=null)
-    {
-        $value =& parent::getRef($name, $default, $reg);
-        if (!$this->input_get_array) {
-            if (isset($this->input_parameters[$name]) && is_array($value) && ($this->input_parameters[$name] === $value)) {
-                // ϥѥ᡼ϡgeta᥽åɤŪ˼
-                $value = null;
-            }
-        }
-        return $value;
-    }
-
-    /**
-     * ϥѥ᡼Ū˼
-     * 
-     * @access public
-     * @param string ץѥƥ̾
-     * @return array ץѥƥ
-     */
-    function geta($name)
-    {
-        if (isset($this->input_parameters[$name]) && is_array($this->input_parameters[$name])) {
-            return $this->input_parameters[$name];
-        } else {
-            return null;
-        }
-    }
-
-    /**
-     * get᥽åѥ᡼ե饰򥻥å
-     * 
-     * @access public
-     * @param bool ѥ᡼ե饰
-     */
-    function isGetArray($input_get_array = false)
-    {
-        $this->input_get_array = (bool)$input_get_array;
-    }
-
     /**
      * JSONPХåؿ򥻥å
      * 
@@ -215,7 +139,7 @@ class SyL_DataJs extends SyL_Data
      */
     function addImport($import)
     {
-        $this->imports = array_merge($this->imports, $import);
+        $this->imports = array_merge($this->imports, (array)$import);
     }
 
     /**
