@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerConsole.php,v 1.14 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerConsole.php,v 1.15 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_LoggerFile.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerConsole.php,v 1.14 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerConsole.php,v 1.15 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_LoggerConsole extends SyL_LoggerFile
@@ -58,7 +58,7 @@ class SyL_LoggerConsole extends SyL_LoggerFile
     function open()
     {
         if ($this->writer == null) {
-            $this->writer =& SyL_File::getObject('writer', 'php://stdout');
+            $this->writer =& SyL_File::factory('w', 'php://stdout');
             $this->writer->open();
         }
     }
