@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.35 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.36 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -64,7 +64,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Container.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.35 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.36 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -142,7 +142,7 @@ class SyL_Controller
         // 󥭡
         define('SYL_ACTION_KEY', (isset($config['action_key']) && $config['action_key']) ? $config['action_key'] : 'action');
         // ץȥǥ쥯ȥ
-        define('SYL_PROJECT_DIR', (isset($config['project_dir']) && $config['project_dir']) ? $config['project_dir'] : SYL_DIR . '/webapp');
+        define('SYL_PROJECT_DIR', $config['project_dir']);
         // ץեǥ쥯ȥ
         define('SYL_PROJECT_CONFIG_DIR',  SYL_PROJECT_DIR . '/config');
         // ץȥ饤֥ǥ쥯ȥ
@@ -171,6 +171,15 @@ class SyL_Controller
             break;
         }
 
+        // PHPƥ२顼¸
+        // ȤǥƤʤ硢¸
+        if (!isset($config['syslog']) || $config['syslog']) {
+            if (!ini_get('log_errors')) {
+                ini_set('log_errors', true);
+                ini_set('error_log', SYL_PROJECT_DIR . '/var/syslogs/' . SYL_APP_NAME . '/phperror_' . date('Ymd') . '.log');
+            }
+        }
+
         // ɤ߹
         SyL_Config::get();
 
