@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDriverMssql.php,v 1.4 2008/08/31 13:58:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDriverMssql.php,v 1.5 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDriverMssql.php,v 1.4 2008/08/31 13:58:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDriverMssql.php,v 1.5 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDriverMssql extends SyL_DB
@@ -71,12 +71,7 @@ class SyL_DBDriverMssql extends SyL_DB
         if ($port)      $host_tmp .= ',' . $port;
 
         $this->connection = $persistent ? mssql_pconnect($host_tmp, $user, $passwd) : mssql_connect($host_tmp, $user, $passwd);
-        if (is_resource($this->connection) && mssql_select_db($dbname, $this->connection)) {
-            $this->setDsnInfo($dbname, $user, $passwd, $host, $port, $persistent);
-            return true;
-        } else {
-            return false;
-        }
+        return (is_resource($this->connection) && mssql_select_db($dbname, $this->connection));
     }
 
     /**
