@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_HttpClientRequest.php,v 1.2 2008/03/01 05:01:22 seasonstream Exp $
+ * @version   CVS: $Id: SyL_HttpClientRequest.php,v 1.3 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once dirname(__FILE__) . '/../Util/SyL_UtilProperty.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_HttpClientRequest.php,v 1.2 2008/03/01 05:01:22 seasonstream Exp $
+ * @version   CVS: $Id: SyL_HttpClientRequest.php,v 1.3 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_HttpClientRequest
@@ -150,6 +150,18 @@ class SyL_HttpClientRequest
         $this->headers->set(strtolower($name), $value);
     }
 
+    /**
+     * إåγǧ
+     * 
+     * @access public
+     * @param string إå̾
+     * @return bool true: إåꡢfalse: إå̵
+     */
+    function isHeader($name)
+    {
+        return $this->headers->is(strtolower($name));
+    }
+
     /**
      * ƤΥإå
      * 
