@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Cache.php,v 1.17 2008/03/01 05:01:22 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Cache.php,v 1.18 2008/03/29 06:11:46 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Cache.php,v 1.17 2008/03/01 05:01:22 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Cache.php,v 1.18 2008/03/29 06:11:46 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Cache
@@ -58,6 +58,13 @@ class SyL_Cache
      * @var string
      */
     var $key_md5 = '';
+    /**
+     * LbV̐ړ
+     *
+     * @access private
+     * @var string
+     */
+    var $prefix = 'syl_cache.';
     /**
      * LbV̗L
      * Pʂ͕b[s]
@@ -81,13 +88,15 @@ class SyL_Cache
      * @var int
      */
     var $max_mtime = 0; // 0:
+
     /**
-     * LbV̐ړ
+     * RXgN^
      *
-     * @access private
-     * @var string
+     * @access public
      */
-    var $prefix = 'syl_cache.';
+    function SyL_Cache()
+    {
+    }
 
     /**
      * LbVIuWFNg擾
@@ -196,6 +205,23 @@ class SyL_Cache
     {
     }
 
+    /**
+     * Kx[WRNVw肵mŋN
+     *
+     * @access public
+     * @param int Nmi0 - 100j
+     */
+    function gc($per)
+    {
+        if (is_numeric($per) && (($per >= 0) && ($per <= 100))) {
+            if (($per > 0) && ($per >= mt_rand(1, 100))) {
+                register_shutdown_function(array(&$this, 'clean'));
+            }
+        } else {
+            trigger_error("[SyL error] Invalid gc method parameter ({$per})", E_USER_ERROR);
+        }
+    }
+
     /**
      * LbV̍XVԂ擾
      *
