@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.24 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.25 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'DB/SyL_DBSchema.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.24 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.25 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -199,7 +199,7 @@ class SyL_DB
         if (!isset($singleton[$dsn]) || !is_object($singleton[$dsn])) {
             $tmp  = explode(':', $dsn, 2);
             $type = ucfirst($tmp[0]);
-            $dbtype = $dbname = $user = $passwd = $host = $port = $persistent = $client_encode = '';
+            $dbtype = $dbname = $user = $passwd = $host = $port = $persistent = $client_encode = null;
             if (isset($tmp[1])) {
                 $tmp = explode(';', $tmp[1]);
                 foreach ($tmp as $tmp2) {
@@ -222,6 +222,7 @@ class SyL_DB
             if (!$singleton[$dsn]->openConnection($dbname, $user, $passwd, $host, $port, $persistent)) {
                 $singleton[$dsn] = null;
             } else {
+                $singleton[$dsn]->setDsnInfo($dbname, $user, $passwd, $host, $port, $persistent);
                 if ($client_encode) {
                     $singleton[$dsn]->setClientEncoding($client_encode);
                 }
@@ -281,7 +282,7 @@ class SyL_DB
         $this->dsn = array(
             'db'         => $dbname,
             'user'       => $user,
-            'password'   => $passwd,
+            //'password'   => $passwd,
             'host'       => $host,
             'port'       => $port,
             'persistent' => $persistent
