@@ -27,15 +27,13 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_File.php,v 1.16 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_File.php,v 1.17 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-/**
- * magic_quotes_runtime ̵
- */
 set_magic_quotes_runtime(0);
+clearstatcache();
 
 /**
  * ե饹
@@ -44,7 +42,7 @@ set_magic_quotes_runtime(0);
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_File.php,v 1.16 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_File.php,v 1.17 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_File
@@ -159,6 +157,53 @@ class SyL_File
         return $file;
     }
 
+    /**
+     * ꥽Ƥ
+     *
+     * @static
+     * @access public
+     * @param string ꥽̾
+     * @return string ꥽
+     */
+    function readContents($resource_name)
+    {
+        return file_get_contents($resource_name);
+    }
+
+    /**
+     * ǡե˽񤭹
+     *
+     * @static
+     * @access public
+     * @param string ե̾
+     * @param string ǡ
+     */
+    function writeContents($resource_name, $data)
+    {
+        $file =& SyL_File::factory('w', $resource_name);
+        $file->open();
+        $file->write($data);
+        $file->close();
+        $file = null;
+    }
+
+    /**
+     * ǡեɵǽ񤭹
+     *
+     * @static
+     * @access public
+     * @param string ե̾
+     * @param string ǡ
+     */
+    function appendContents($resource_name, $data)
+    {
+        $file =& SyL_File::factory('a', $resource_name);
+        $file->open();
+        $file->write($data);
+        $file->close();
+        $file = null;
+    }
+
     /**
      * ե򳫤
      *
@@ -167,8 +212,6 @@ class SyL_File
      */
     function open()
     {
-        clearstatcache();
-
         if ($this->current_umask !== null) {
             $this->current_umask = umask(0000);
         }
@@ -204,67 +247,6 @@ class SyL_File
         }
     }
 
-    /**
-     * ե뤫ɤ߹
-     *
-     * @access protected
-     * @return string ϥǡ or bool(false) ɤ߹߽λ
-     */
-    function read() {}
-
-    /**
-     * ե˽Ϥ
-     *
-     * @access protected
-     * @param string ϥå
-     */
-    function write($message) {}
-
-    /**
-     * ե˽Ϥ˲Ԥղä
-     *
-     * @access protected
-     * @param string ϥå
-     */
-    function writeln($message) {}
-
-    /**
-     * եΰϢ¹Ԥʥ֥Ⱥʳ
-     *
-     * @access protected
-     * @param string ϥå
-     * @return string եΥǡ
-     */
-    function process($message='')
-    {
-    }
-
-    /**
-     * եΰϢ¹Ԥʥ֥Ⱥޤ
-     *
-     * @static
-     * @access protected
-     * @param string ե
-     * @param string ե̾
-     * @param string եΥǡ
-     * @return string եΥǡ
-     */
-    function processAll($type, $resource_name, $message='')
-    {
-        $file =& SyL_File::factory($type, $resource_name);
-        switch (strtolower($type)) {
-        case 'r':
-            $message = $file->process();
-            break;
-        case 'w': 
-        case 'a': 
-            $file->process($message);
-            $message = null;
-            break;
-        }
-        return $message;
-    }
-
     /**
      * CSVեѤ
      *
