@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_WebServiceYahoo_co_jp.php,v 1.4 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_WebServiceYahoo_co_jp.php,v 1.5 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -51,7 +51,7 @@ require_once dirname(__FILE__) . '/Yahoo_co_jp/SyL_WebServiceYahoo_co_jpResponse
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_WebServiceYahoo_co_jp.php,v 1.4 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_WebServiceYahoo_co_jp.php,v 1.5 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_WebServiceYahoo_co_jp extends SyL_WebService
@@ -66,10 +66,10 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʥָѡ
      */
-    function &createWebSearchRequest()
+    function &createSearchWebRequest()
     {
-        $class_name = 'SyL_WebServiceSearchWebSearchRequest';
-        include_once dirname(__FILE__) . '/Yahoo_co_jp/Search/WebSearch/' . $class_name . '.php';
+        $class_name = 'SyL_WebServiceSearchWebRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Search/Web/' . $class_name . '.php';
         $request =& new $class_name();
         return $request;
     }
@@ -80,10 +80,10 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʲѡ
      */
-    function &createImageSearchRequest()
+    function &createSearchImageRequest()
     {
-        $class_name = 'SyL_WebServiceSearchImageSearchRequest';
-        include_once dirname(__FILE__) . '/Yahoo_co_jp/Search/ImageSearch/' . $class_name . '.php';
+        $class_name = 'SyL_WebServiceSearchImageRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Search/Image/' . $class_name . '.php';
         $request =& new $class_name();
         return $request;
     }
@@ -94,10 +94,10 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡư踡ѡ
      */
-    function &createVideoSearchRequest()
+    function &createSearchVideoRequest()
     {
-        $class_name = 'SyL_WebServiceSearchVideoSearchRequest';
-        include_once dirname(__FILE__) . '/Yahoo_co_jp/Search/VideoSearch/' . $class_name . '.php';
+        $class_name = 'SyL_WebServiceSearchVideoRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Search/Video/' . $class_name . '.php';
         $request =& new $class_name();
         return $request;
     }
@@ -108,10 +108,10 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʴϢѡ
      */
-    function &createWebunitSearchRequest()
+    function &createSearchWebunitRequest()
     {
-        $class_name = 'SyL_WebServiceSearchWebunitSearchRequest';
-        include_once dirname(__FILE__) . '/Yahoo_co_jp/Search/WebunitSearch/' . $class_name . '.php';
+        $class_name = 'SyL_WebServiceSearchWebunitRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Search/Webunit/' . $class_name . '.php';
         $request =& new $class_name();
         return $request;
     }
@@ -126,10 +126,10 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʥǥ쥯ȥĥ꡼ѡ
      */
-    function &createCategoryRequest()
+    function &createCategoryBrowseRequest()
     {
-        $class_name = 'SyL_WebServiceCategoryCategoryRequest';
-        include_once dirname(__FILE__) . '/Yahoo_co_jp/Category/Category/' . $class_name . '.php';
+        $class_name = 'SyL_WebServiceCategoryBrowseRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Category/Browse/' . $class_name . '.php';
         $request =& new $class_name();
         return $request;
     }
@@ -140,10 +140,10 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʥǥ쥯ȥꥵѡ
      */
-    function &createDirectorySearchRequest()
+    function &createCategorySearchRequest()
     {
-        $class_name = 'SyL_WebServiceCategoryDirectorySearchRequest';
-        include_once dirname(__FILE__) . '/Yahoo_co_jp/Category/DirectorySearch/' . $class_name . '.php';
+        $class_name = 'SyL_WebServiceCategorySearchRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Category/Search/' . $class_name . '.php';
         $request =& new $class_name();
         return $request;
     }
@@ -158,7 +158,7 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʥ - ƥѡ
      */
-    function &createCategoryTreeRequest()
+    function &createAuctionCategoryTreeRequest()
     {
         $class_name = 'SyL_WebServiceAuctionCategoryTreeRequest';
         include_once dirname(__FILE__) . '/Yahoo_co_jp/Auction/CategoryTree/' . $class_name . '.php';
@@ -172,7 +172,7 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʥ - ʥꥹѡ
      */
-    function &createCategoryLeafRequest()
+    function &createAuctionCategoryLeafRequest()
     {
         $class_name = 'SyL_WebServiceAuctionCategoryLeafRequest';
         include_once dirname(__FILE__) . '/Yahoo_co_jp/Auction/CategoryLeaf/' . $class_name . '.php';
@@ -186,7 +186,7 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʥ - ʥꥹѡ
      */
-    function &createSellingListRequest()
+    function &createAuctionSellingListRequest()
     {
         $class_name = 'SyL_WebServiceAuctionSellingListRequest';
         include_once dirname(__FILE__) . '/Yahoo_co_jp/Auction/SellingList/' . $class_name . '.php';
@@ -200,7 +200,7 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʥ - ѡ
      */
-    function &createSearchRequest()
+    function &createAuctionSearchRequest()
     {
         $class_name = 'SyL_WebServiceAuctionSearchRequest';
         include_once dirname(__FILE__) . '/Yahoo_co_jp/Auction/Search/' . $class_name . '.php';
@@ -214,7 +214,7 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʥ - ʾܺѡ
      */
-    function &createAuctionItemRequest()
+    function &createAuctionAuctionItemRequest()
     {
         $class_name = 'SyL_WebServiceAuctionAuctionItemRequest';
         include_once dirname(__FILE__) . '/Yahoo_co_jp/Auction/AuctionItem/' . $class_name . '.php';
@@ -232,10 +232,10 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʥɥơȥꥹѡ
      */
-    function &createProgramListRequest()
+    function &createMusicStationRequest()
     {
-        $class_name = 'SyL_WebServiceMusicProgramListRequest';
-        include_once dirname(__FILE__) . '/Yahoo_co_jp/Music/ProgramList/' . $class_name . '.php';
+        $class_name = 'SyL_WebServiceMusicStationRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Music/Station/' . $class_name . '.php';
         $request =& new $class_name();
         return $request;
     }
@@ -250,7 +250,7 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡϿ޾ - 륵API
      */
-    function &createLocalSearchRequest()
+    function &createMapLocalSearchRequest()
     {
         $class_name = 'SyL_WebServiceMapLocalSearchRequest';
         include_once dirname(__FILE__) . '/Yahoo_co_jp/Map/LocalSearch/' . $class_name . '.php';
@@ -268,10 +268,10 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡܸǲWebӥ
      */
-    function &createParseRequest()
+    function &createJlpMAServiceRequest()
     {
-        $class_name = 'SyL_WebServiceTextParseRequest';
-        include_once dirname(__FILE__) . '/Yahoo_co_jp/Text/Parse/' . $class_name . '.php';
+        $class_name = 'SyL_WebServiceJlpMAServiceRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Jlp/MAService/' . $class_name . '.php';
         $request =& new $class_name();
         return $request;
     }
@@ -282,10 +282,10 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʤʴѴWebӥ
      */
-    function &createConversionRequest()
+    function &createJlpJIMServiceRequest()
     {
-        $class_name = 'SyL_WebServiceTextConversionRequest';
-        include_once dirname(__FILE__) . '/Yahoo_co_jp/Text/Conversion/' . $class_name . '.php';
+        $class_name = 'SyL_WebServiceJlpJIMServiceRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Jlp/JIMService/' . $class_name . '.php';
         $request =& new $class_name();
         return $request;
     }
@@ -296,10 +296,52 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʹٱWebӥ
      */
-    function &createKouseiRequest()
+    function &createJlpKouseiServiceRequest()
     {
-        $class_name = 'SyL_WebServiceTextKouseiRequest';
-        include_once dirname(__FILE__) . '/Yahoo_co_jp/Text/Kousei/' . $class_name . '.php';
+        $class_name = 'SyL_WebServiceJlpKouseiServiceRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Jlp/KouseiService/' . $class_name . '.php';
+        $request =& new $class_name();
+        return $request;
+    }
+
+    /**
+     * WEBӥꥯȥ֥ȤʥӿWebӥ
+     * 
+     * @access public
+     * @return object WEBӥꥯȥ֥ȡʥӿWebӥ
+     */
+    function &createJlpFuriganaServiceRequest()
+    {
+        $class_name = 'SyL_WebServiceJlpFuriganaServiceRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Jlp/FuriganaService/' . $class_name . '.php';
+        $request =& new $class_name();
+        return $request;
+    }
+
+    /**
+     * WEBӥꥯȥ֥Ȥܸ췸Webӥ
+     * 
+     * @access public
+     * @return object WEBӥꥯȥ֥ȡܸ췸Webӥ
+     */
+    function &createJlpDAServiceRequest()
+    {
+        $class_name = 'SyL_WebServiceJlpDAServiceRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Jlp/DAService/' . $class_name . '.php';
+        $request =& new $class_name();
+        return $request;
+    }
+
+    /**
+     * WEBӥꥯȥ֥Ȥʻƻ췸踡Webӥ
+     * 
+     * @access public
+     * @return object WEBӥꥯȥ֥ȡʻƻ췸踡Webӥ
+     */
+    function &createJlpDAServiceSearchRequest()
+    {
+        $class_name = 'SyL_WebServiceJlpDAServiceSearchRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Jlp/DAServiceSearch/' . $class_name . '.php';
         $request =& new $class_name();
         return $request;
     }
@@ -314,7 +356,7 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʸ
      */
-    function &createProductSearchRequest()
+    function &createKadenProductSearchRequest()
     {
         $class_name = 'SyL_WebServiceKadenProductSearchRequest';
         include_once dirname(__FILE__) . '/Yahoo_co_jp/Kaden/ProductSearch/' . $class_name . '.php';
@@ -328,7 +370,7 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʾ
      */
-    function &createProductItemRequest()
+    function &createKadenProductItemRequest()
     {
         $class_name = 'SyL_WebServiceKadenProductItemRequest';
         include_once dirname(__FILE__) . '/Yahoo_co_jp/Kaden/ProductItem/' . $class_name . '.php';
@@ -355,7 +397,7 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
     }
 
     // -----------------------------------------------------
-    // Yahoo!󥿡ͥåȸ
+    // Yahoo!ߤʤθ
     // -----------------------------------------------------
 
     /**
@@ -364,7 +406,7 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʤߤʤθ ꥹWebӥ
      */
-    function &createCertListRequest()
+    function &createMinnaCertCertListRequest()
     {
         $class_name = 'SyL_WebServiceMinnaCertCertListRequest';
         include_once dirname(__FILE__) . '/Yahoo_co_jp/MinnaCert/CertList/' . $class_name . '.php';
@@ -378,7 +420,7 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʤߤʤθ ܺWebӥ
      */
-    function &createCertDetailRequest()
+    function &createMinnaCertCertDetailRequest()
     {
         $class_name = 'SyL_WebServiceMinnaCertCertDetailRequest';
         include_once dirname(__FILE__) . '/Yahoo_co_jp/MinnaCert/CertDetail/' . $class_name . '.php';
@@ -392,7 +434,7 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
      * @access public
      * @return object WEBӥꥯȥ֥ȡʤߤʤθ Webӥ
      */
-    function &createCertExamRequest()
+    function &createMinnaCertCertExamRequest()
     {
         $class_name = 'SyL_WebServiceMinnaCertCertExamRequest';
         include_once dirname(__FILE__) . '/Yahoo_co_jp/MinnaCert/CertExam/' . $class_name . '.php';
