@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.7 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.8 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ SyL_Loader::lib('File');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.7 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.8 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Index extends AppAction
@@ -481,15 +481,13 @@ class Index extends AppAction
         $cmd->stdout("  table template file {$template_table_file}");
         $cmd->stdout("    -> generating table file {$table_file}");
 
-        $file =& SyL_File::factory('w', $table_file);
-        $file->process(str_replace($table_search, $table_replace, file_get_contents($template_table_file)));
+        SyL_File::writeContents($table_file, str_replace($table_search, $table_replace, file_get_contents($template_table_file)));
 
         // եե
         $cmd->stdout("  form template file {$template_form_file}");
         $cmd->stdout("    -> generating form file {$form_file}");
 
-        $file =& SyL_File::factory('w', $form_file);
-        $file->process(str_replace($form_search, $form_replace, file_get_contents($template_form_file)));
+        SyL_File::writeContents($form_file, str_replace($form_search, $form_replace, file_get_contents($template_form_file)));
 
         if ($action_name) {
             // ե
@@ -498,56 +496,49 @@ class Index extends AppAction
             $cmd->stdout("  action template file {$template_file}");
             $cmd->stdout("    -> generating form file {$create_file}");
 
-            $file =& SyL_File::factory('w', $create_file);
-            $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
+            SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Lst.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}");
             $cmd->stdout("    -> generating form file {$create_file}");
 
-            $file =& SyL_File::factory('w', $create_file);
-            $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
+            SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/New.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}");
             $cmd->stdout("    -> generating form file {$create_file}");
 
-            $file =& SyL_File::factory('w', $create_file);
-            $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
+            SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Upd.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}");
             $cmd->stdout("    -> generating form file {$create_file}");
 
-            $file =& SyL_File::factory('w', $create_file);
-            $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
+            SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Del.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}");
             $cmd->stdout("    -> generating form file {$create_file}");
 
-            $file =& SyL_File::factory('w', $create_file);
-            $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
+            SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Fin.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}");
             $cmd->stdout("    -> generating form file {$create_file}");
 
-            $file =& SyL_File::factory('w', $create_file);
-            $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
+            SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Vew.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}");
             $cmd->stdout("    -> generating form file {$create_file}");
 
-            $file =& SyL_File::factory('w', $create_file);
-            $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
+            SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             // ƥץ졼ȥե
             $dir = ($smarty_flag) ? 'smarty' : 'default';
@@ -557,40 +548,35 @@ class Index extends AppAction
             $cmd->stdout("  template template file {$template_file}");
             $cmd->stdout("    -> generating form file {$create_file}");
 
-            $file =& SyL_File::factory('w', $create_file);
-            $file->process(file_get_contents($template_file));
+            SyL_File::writeContents($create_file, file_get_contents($template_file));
 
             $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/New.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
             $cmd->stdout("  template template file {$template_file}");
             $cmd->stdout("    -> generating form file {$create_file}");
 
-            $file =& SyL_File::factory('w', $create_file);
-            $file->process(file_get_contents($template_file));
+            SyL_File::writeContents($create_file, file_get_contents($template_file));
 
             $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Upd.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
             $cmd->stdout("  template template file {$template_file}");
             $cmd->stdout("    -> generating form file {$create_file}");
 
-            $file =& SyL_File::factory('w', $create_file);
-            $file->process(file_get_contents($template_file));
+            SyL_File::writeContents($create_file, file_get_contents($template_file));
 
             $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Fin.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
             $cmd->stdout("  template template file {$template_file}");
             $cmd->stdout("    -> generating form file {$create_file}");
 
-            $file =& SyL_File::factory('w', $create_file);
-            $file->process(file_get_contents($template_file));
+            SyL_File::writeContents($create_file, file_get_contents($template_file));
 
             $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Vew.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
             $cmd->stdout("  template template file {$template_file}");
             $cmd->stdout("    -> generating form file {$create_file}");
 
-            $file =& SyL_File::factory('w', $create_file);
-            $file->process(file_get_contents($template_file));
+            SyL_File::writeContents($create_file, file_get_contents($template_file));
         }
 
         // ե륳ԡ
